@@ -6,8 +6,8 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="gnomba"
 
-(test -f $srcdir/configure.in \
-  && test -f $srcdir/gnomba.c) || {
+(test -f configure.in \
+  && test -f $srcdir/src/gnomba.c) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level gnomba directory"
     exit 1
